##  Overview
The Application Portfolio Management Onboarding Dashboard for enterprise architects supports them in their onboarding journey, offering guidance and enablement resources essential to get started with SAP LeanIX Application Portfolio Management.
